testinggtk r154 - trunk/tests/gobject
- From: bjornl svn gnome org
- To: svn-commits-list gnome org
- Subject: testinggtk r154 - trunk/tests/gobject
- Date: Fri, 20 Jun 2008 19:47:12 +0000 (UTC)
Author: bjornl
Date: Fri Jun 20 19:47:11 2008
New Revision: 154
URL: http://svn.gnome.org/viewvc/testinggtk?rev=154&view=rev
Log:
Test creating different types of properties
Modified:
trunk/tests/gobject/test_properties.py
Modified: trunk/tests/gobject/test_properties.py
==============================================================================
--- trunk/tests/gobject/test_properties.py (original)
+++ trunk/tests/gobject/test_properties.py Fri Jun 20 19:47:11 2008
@@ -35,8 +35,22 @@
def test_create_char_property():
'''
Check that it is possible to create a property of tye
``gobject.TYPE_CHAR``.
+
+ :bug: #539355
'''
prop = gobject.property(type = gobject.TYPE_CHAR)
assert prop.type == gobject.TYPE_CHAR
+ type, nick, blurb, flags = prop.get_pspec_args()
+
+def test_create_pointer_property():
+ '''
+ Check that it is possible to create a property of type
+ ``gobject.TYPE_POINTER``.
+
+ :bug: #539355
+ '''
+ prop = gobject.property(type = gobject.TYPE_POINTER)
+ assert prop.type == gobject.TYPE_POINTER
+ type, nick, blurb, flags = prop.get_pspec_args()
[
Date Prev][
Date Next] [
@@ -35,8 +35,22 @@
def test_create_char_property():
'''
- Check that it is possible to create a property of tye
+ Check that it is possible to create a property of type
``gobject.TYPE_CHAR``.
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]